@@ -29,7 +29,9 @@ POST='POST'
 -15: 类型错误（e.g. ls 传入文件, download 传入文件夹)
 -11 ~ -13: 命名冲突: -11: 与末端文件名相同, -12: 与文件夹名相同, -13: 与前面的文件名相同
 -18: 复制或移动时 source 包含 target
+-24: 空间不足
 -25: 读取本地文件失败
+-30: http 错误
 10: 写入文件失败
 '''
 
@@ -52,6 +54,8 @@ def ls(folder:str):
     url='https://api.dropboxapi.com/2/files/list_folder'
     r=http(url,Method=POST,Header=header,Body=body)
     # print(r)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -88,6 +92,8 @@ def mkdir(path:str):
     body={'path':path}
     body=dumps(body)
     r=http(url,Method=POST,Header=header,Body=body)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -117,6 +123,8 @@ def rm(target:str):
     body={'path':target}
     body=dumps(body)
     r=http(url,Method=POST,Header=header,Body=body)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -130,7 +138,7 @@ def rm(target:str):
 
 def cp(source:str,target:str):
     # 必须添加目标文件名或文件夹名
-    # -21: source 格式不合法, -22: target 格式不合法
+    # -21: source 格式不合法, -22: target 格式不合法, -24: 空间不足
     # -10: 不存在, -11: 与末端文件名相同, -12: 与文件夹名相同, -13: 与前面的文件名相同 -18: source 包含 target
     access_token=getAccessToken()
     if(type(access_token)==type(0)):
@@ -149,6 +157,11 @@ def cp(source:str,target:str):
     body={'from_path':source,'to_path':target}
     body=dumps(body)
     r=http(url,Method=POST,Header=header,Body=body)
+    if(str(r['text']).find('nsufficient_quota')>=0):
+        return -24
+    # print(r)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -191,6 +204,8 @@ def mv(source:str,target:str):
     body={'from_path':source,'to_path':target}
     body=dumps(body)
     r=http(url,Method=POST,Header=header,Body=body)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -247,6 +262,8 @@ def download(path:str,LocalPath=None):
     }
     r=http(url,Method=POST,Header=header,Retry=False,Decode=False)
     #print(r)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return [r['status'],None]
     if(r['code']==401):
@@ -285,12 +302,14 @@ def downloadFolder(path,localPath):
     }
     r=http(url,Method=POST,Header=header,Retry=False,Decode=False)
     # print(r)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return [r['status'],None]
     if(r['code']==401):
         return [-9,None]
     if(r['code']!=200):
-        if(str(r['text']).find('Invalid path: INVALID_PATH')>=0):
+        if(str(r['text']).find('Invalid path: INVALID_PATH')>=0 or str(r['text']).find('nvalid path')>=0):
             return [-20,None]
         if(str(r['text']).find('not_found')>=0):
             return [-10,None]
@@ -309,7 +328,7 @@ def upload(path:str,file,Timeout=1000):
     # Timeout 单位为 s
     # file 为本地文件路径(字符串)或二进制字符串
     # 如果是二进制字符串, 直接上传, 如果是本地文件路径, 打开读取内容后上传
-    # -30: 读取文件失败, -20: 文件名格式不合法
+    # -30: 读取文件失败, -20: 文件名格式不合法, -24: 空间不足
     if(type(file)!=type('') and type(file)!=type(b'')):
         raise InputError('The parameter file must be str or bytes.')
     access_token=getAccessToken()
@@ -334,6 +353,10 @@ def upload(path:str,file,Timeout=1000):
     timeout=1000*Timeout
     r=http(url,Method=POST,Header=header,Retry=False,Decode=False,Body=file,Timeout=timeout)
     # print(r)
+    if(str(r['text']).find('nsufficient_space')>=0):
+        return -24
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return [r['status'],None]
     if(r['code']==401):
@@ -367,6 +390,8 @@ def ls_l(folder:str):
     url='https://api.dropboxapi.com/2/files/list_folder'
     r=http(url,Method=POST,Header=header,Body=body)
     # print(dumps(r['text']))
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -402,6 +427,8 @@ def getFileProperty(file:str):
     body={'path':file}
     body=dumps(body)
     r=http(url,Method=POST,Header=header,Body=body)
+    if(r['code']>=300 and r['code']<=399):
+        return -30
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -414,6 +441,22 @@ def getFileProperty(file:str):
         return -15
     return [r['text']['size'],toUnix(r['text']['client_modified']),toUnix(r['text']['server_modified'])]
 
+
+
+def Type(path:str):
+    # 文件: 1, 文件夹: 2, 不存在: 0
+    s=getFileProperty(path)
+    if(s==-15):
+        return 1
+    if(s==-10):
+        return 0
+    if(type(s)==type(0)):
+        return s
+    return 2
+
+
+
+
 def search():
     pass
 
